# Table of Contents

- [advanced-filter-options](<./advanced-filter-options.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Advanced Filter Options](<./Advanced-Filter-Options.md>)
  - [Introduction](<./Advanced-Filter-Options/Introduction.md>)
  - [Advanced Filtering](<./Advanced-Filter-Options/Advanced-Filtering.md>)
  - [Combining Filters with AND, OR, and IS NOT Logic](<./Advanced-Filter-Options/Combining-Filters-with-AND-OR-and-IS-NOT-Logic.md>)
  - [Filtering by Fields on Relation](<./Advanced-Filter-Options/Filtering-by-Fields-on-Relation.md>)
  - [Inverting Applied Fields on Relation Filter](<./Advanced-Filter-Options/Inverting-Applied-Fields-on-Relation-Filter.md>)
  - [Making Fact Sheet Fields Available as Filter Options](<./Advanced-Filter-Options/Making-Fact-Sheet-Fields-Available-as-Filter-Options.md>)
  - [Using the Lifecycle Filter](<./Advanced-Filter-Options/Using-the-Lifecycle-Filter.md>)
  - [Filtering by Subscriptions](<./Advanced-Filter-Options/Filtering-by-Subscriptions.md>)
  - [Listing the Fact Sheets Without Subscriptions](<./Advanced-Filter-Options/Listing-the-Fact-Sheets-Without-Subscriptions.md>)
  - [Listing All Fact Sheets with a Specific Subscription Type or Role](<./Advanced-Filter-Options/Listing-All-Fact-Sheets-with-a-Specific-Subscription-Type-or-Role.md>)
